%define BUILD_python 0

%define ALD_Ver		1.2.1

Name:         libxslt

License:      MIT
Summary:      Library providing the Gnome XSLT engine
Group:        Development/Libraries
Version:      1.1.27
Release:      2
URL: http://xmlsoft.org/XSLT/

Requires: libxml2 >= 2.6.27

Source: %{name}-%{version}.tar.xz
Source1: CROSS.sh

%define DestDir		/xml
# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%define BUILD_LOCAL_CROSS 0
%else
# rpm --target=x86_64/armv6l/win32 -ba xxxxx.spec
%define _CROSS 1
%define BUILD_LOCAL_CROSS 1
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1
#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
%define target %{_arch}-%{_vendor}-%{_os}%{__isa_bits}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif
%define target_  %{target}-

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/bin

%define __os_install_post %{nil}

%define cross_bindir	%{csysdir}%{_bindir}
%define cross_libdir	%{csysdir}%{_libdir}
%define cross_includedir %{csysdir}%{_includedir}
%define cross_datadir	%{csysdir}%{_datadir}
%define cross_infodir	%{csysdir}%{_infodir}
%define cross_mandir	%{csysdir}%{_mandir}
%define cross_defaultdocdir %{csysdir}%{_defaultdocdir}
%define cross_docdir	%{cross_defaultdocdir}/%{name}

%define CrossDestDir	/Cross

%define _srcrpmdir	%{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysbindir	%{_prefix}/bin
%define CrossDestDir	%{nil}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}

%define target_  %{nil}
%define target %{_build}

%endif # !_CROSS

%define docdir %{_defaultdocdir}/%{name}
# ------------------- description ------------------------------------
%description
This C library allows to transform XML files into other XML files
(or HTML, text, ...) using the standard XSLT stylesheet transformation
mechanism. To use it you need to have a version of libxml2 >= 2.6.27
installed. The xsltproc command is a command line interface to the XSLT engine
#-------------------------------
%package devel
Summary:      Libraries for the C compiler
Group:        Development/Libraries
Requires: libxslt = %{version}
Requires: libxml2-devel >= 2.6.27
%description devel
These libraries are needed to compile C code.
#-------------------------------

%if %BUILD_python
%package python
Summary: Python bindings for the libxslt library
Group: Development/Libraries
Requires: libxslt = %{version}
Requires: libxml2 >= 2.6.27
Requires: libxml2-python >= 2.6.27

%description python
The libxslt-python package contains a module that permits applications
written in the Python programming language to use the interface
supplied by the libxslt library to apply XSLT transformations.
%endif
#-------------------------------
%package doc
Summary:      doc for %{name}
Group:        Documentation
%description doc
doc for %{name}
#-------------------------------
%package %{TO_ARCH}
Summary:      %{name} Cross-%{TO_ARCH} Libraries
Group:        Development/Libraries
%description %{TO_ARCH}
%{name} Cross-%{TO_ARCH} Libraries

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-%{version}
sed -i s:"@XSLT_LIBDIR@ ":: xslt-config.in

# ------------------- Build ------------------------------------------
%Build 
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

%if %{_arch} == "i386"
OPTFLAGS="-O2 -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-O2 -fno-asynchronous-unwind-tables"
%endif
%if %{_arch} == "arm"
OPTFLAGS="-O2 -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
%endif

%if %{_os} == "mingw"
CFLAGS="$OPTFLAGS -std=gnu99"
LDFLAGS=" "
%else
CFLAGS="$OPTFLAGS -std=gnu99"
GCC_VER_STR=`%{target_}gcc -dumpversion`
LDFLAGS=`case $GCC_VER_STR in \
 4.[56789].*) echo -static-libgcc ;; \
 esac`
LDFLAGS="$LDFLAGS "
%endif

%configure \
	--build=%{_build} \
%if %{_CROSS}
	--host=%{target} \
%endif
%if %{_os} == "mingw"
	--disable-shared \
%else
	--enable-shared \
	--disable-static \
%endif
	--with-html-dir=%{_defaultdocdir} \
	--without-debug \
	--without-debugger \
	--disable-libtool-lock \
	--without-python \
	--without-crypto \
	&>FConfigure_log.txt

make &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}

make DESTDIR=$RPM_BUILD_ROOT install &>FInstall_log.txt
rm $RPM_BUILD_ROOT%{_libdir}/*.la
mv $RPM_BUILD_ROOT%{_defaultdocdir}/%{name}-%{version} $RPM_BUILD_ROOT%{docdir}

cp AUTHORS COPYING Copyright FEATURES README $RPM_BUILD_ROOT%{docdir}/

%if %{_CROSS}
sed -i s:"-L%{cross_libdir} ":: $RPM_BUILD_ROOT%{_bindir}/xslt-config
sed -i s:"-L%{cross_libdir} ":: $RPM_BUILD_ROOT%{_libdir}/xsltConf.sh
%else
sed -i s:"-L%{_libdir} ":: $RPM_BUILD_ROOT%{_bindir}/xslt-config
sed -i s:"-L%{_libdir} ":: $RPM_BUILD_ROOT%{_libdir}/xsltConf.sh
%endif

%if %{_CROSS}
TARGET_PRFIX=%{_prefix}
TARGET_CROSS_PRFIX=%{csysdir}
TARGET_NAME=%{target}
MKCROSSDIR=%{BUILD_LOCAL_CROSS}
export TARGET_PRFIX TARGET_CROSS_PRFIX TARGET_NAME MKCROSSDIR
%SOURCE1
%if %{BUILD_LOCAL_CROSS}
rm $RPM_BUILD_ROOT%{cross_bindir}/xsltproc
rm -r $RPM_BUILD_ROOT%{cross_libdir}/libxslt-plugins
mv $RPM_BUILD_ROOT%{cross_bindir} $RPM_BUILD_ROOT%{csysbindir}
sed -i s:"/usr/include":"%{csysdir}/usr/include": $RPM_BUILD_ROOT%{csysbindir}/xslt-config
sed -i s:"/usr":"%{csysdir}/usr": $RPM_BUILD_ROOT%{cross_libdir}/xsltConf.sh

rm -r $RPM_BUILD_ROOT%{cross_docdir}/html
rm -r $RPM_BUILD_ROOT%{cross_mandir}
%endif #BUILD_LOCAL_CROSS
%endif #_CROSS

%if !%{_CROSS}
if test -f /opt/aldccp/bin/packages_idx; then
  /opt/aldccp/bin/packages_idx -p %{name} -v %{version} -r %{DestDir} $RPM_BUILD_ROOT
fi
%endif

# ------------------- Clean ------------------------------------------
%Clean
DE=%{version}-%{release}.%{TO_ARCH}.rpm
DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{DestDir}
DEC=%{version}-%{release}.%{_build_cpu}.rpm
DDC=%{_rpmdir}/%{_build_cpu}/%{ALD_Ver}%{CrossDestDir}/%{TO_ARCH}%{DestDir}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
%if (%{_os} == "mingw")
  rm %{name}-$SE
%if %{BUILD_LOCAL_CROSS}
  mkdir -p $DDC
  mv %{name}-%{TO_ARCH}-$SE $DDC/%{name}-%{TO_ARCH}-$DEC
%endif #BUILD_LOCAL_CROSS
%else  #mingw
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
  mv %{name}-devel-$SE $DD/%{name}-devel-$DE
  mv %{name}-doc-$SE $DD/%{name}-doc-$DE
%if %{BUILD_LOCAL_CROSS}
  mkdir -p $DDC
  mv %{name}-%{TO_ARCH}-$SE $DDC/%{name}-%{TO_ARCH}-$DEC
%endif #BUILD_LOCAL_CROSS
%endif #!mingw
popd

# --------------- build *.tgz ------------------------
%if %{BUILD_TAR}
pushd $RPM_BUILD_ROOT
%if (%{_os} == "mingw")
  TMP_TO=$DD
%else
  TMP_TO=$DD/tar
%endif
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}.%{TO_ARCH}
  mkdir -p $tmp
  cp -r usr $tmp/
%if (%{_os} == "mingw")
  zip -9 -r $tmp.zip $tmp >/dev/null
  mv $tmp.zip $TMP_TO
%else
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
%endif
  rm -r $tmp
%if %{BUILD_LOCAL_CROSS}
  TMP_TO=$DDC/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{TO_ARCH}-%{version}-%{release}.%{_build_cpu}
  mkdir -p $tmp
  cp -r cross $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
%endif
popd
%endif  #BUILD_TAR

# ------------------- Files ------------------------------------------
%if %{_os} == "mingw"
%Files
%{_prefix}

%if %{BUILD_LOCAL_CROSS}
%Files %{TO_ARCH}
%{csysdir}
%endif #!BUILD_LOCAL_CROSS
%else  #mingw

%Files
%{_bindir}/xsltproc
%{_libdir}/*.so.*
%{_mandir}/man1
%{docdir}/AUTHORS
%{docdir}/COPYING
%{docdir}/Copyright
%{docdir}/FEATURES
%{docdir}/README

%files devel
%{_bindir}/xslt-config
%{_includedir}
%{_libdir}/*.so
%{_libdir}/*.sh
%{_libdir}/pkgconfig
%{_datadir}/aclocal
%{_mandir}/man3

%if %BUILD_python
%files python
%{_libdir}/python2.5
%endif

%files doc
%{docdir}/html

# ------------------- Cross Files ------------------------------------
%if %{BUILD_LOCAL_CROSS}

%Files %{TO_ARCH}
%{csysbindir}
%{cross_libdir}
%{cross_includedir}
%{cross_datadir}

%endif #!BUILD_LOCAL_CROSS
%endif #!mingw
